@@ -23,7 +23,8 @@
 #'  `tidy` method, a tibble with columns `terms` (the
 #'  columns that will be affected) and `base`.
 #' @keywords datagen
-#' @concept preprocessing transformation_methods
+#' @concept preprocessing
+#' @concept transformation_methods
 #' @export
 #' @examples
 #' set.seed(313)
@@ -138,7 +139,7 @@ bake.step_log <- function(object, new_data, ...) {
         log(new_data[[ col_names[i] ]] + object$offset, base = object$base)
   } else {
     if (object$offset != 0)
-      warning("When signed is TRUE, offset will be ignored")
+      rlang::warn("When signed is TRUE, offset will be ignored")
      for (i in seq_along(col_names))
        new_data[, col_names[i]] <-
          ifelse(abs(new_data[[ col_names[i] ]]) < 1,
