@@ -1,4 +1,4 @@
-#' Check for Missing Values
+#' Check for New Values
 #'
 #' `check_new_values` creates a a *specification* of a recipe
 #'  operation that will check if variables contain new values.
@@ -35,6 +35,7 @@
 #'  columns does contain values it did not contain when `prep` was called
 #'  on the recipe. If the check passes, nothing is changed to the data.
 #' @examples
+#' library(modeldata)
 #' data(credit_data)
 #'
 #' # If the test passes, `new_data` is returned unaltered
@@ -113,10 +114,11 @@ new_values_func <- function(x,
   if (length(new_vals) == 0) return()
   if (all(is.na(new_vals)) && ignore_NA) return()
   if (ignore_NA) new_vals <- new_vals[!is.na(new_vals)]
-  stop(colname,
-       " contains the new value(s): ",
-       paste(new_vals, collapse = ","),
-       call. = FALSE)
+  rlang::abort(paste0(
+    colname,
+    " contains the new value(s): ",
+    paste(new_vals, collapse = ",")
+  ))
 }
 
 prep.check_new_values <- function(x, training, info = NULL, ...) {
