@@ -11,8 +11,13 @@
 #'  currently used.
 #' @param role Not used by this step since no new variables are
 #'  created.
-#' @param sds A named numeric vector of standard deviations This
+#' @param sds A named numeric vector of standard deviations. This
 #'  is `NULL` until computed by [prep.recipe()].
+#' @param factor A numeric value of either 1 or 2 that scales the
+#'  numeric inputs by one or two standard deviations. By dividing
+#'  by two standard deviations, the coefficients attached to
+#'  continous predictors can be interpreted the same way as with
+#'  binary inputs. Defaults to `1`. More in reference below.
 #' @param na_rm A logical value indicating whether `NA`
 #'  values should be removed when computing the standard deviation.
 #' @return An updated version of `recipe` with the new step
@@ -30,7 +35,11 @@
 #'  `training` argument of `prep.recipe`.
 #'  `bake.recipe` then applies the scaling to new data sets
 #'  using these standard deviations.
+#' @references Gelman, A. (2007) "Scaling regression inputs by
+#'  dividing by two standard deviations." Unpublished. Source:
+#'  \url{http://www.stat.columbia.edu/~gelman/research/unpublished/standardizing.pdf}.
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -57,6 +66,7 @@ step_scale <-
            role = NA,
            trained = FALSE,
            sds = NULL,
+           factor = 1,
            na_rm = TRUE,
            skip = FALSE,
            id = rand_id("scale")) {
@@ -67,6 +77,7 @@ step_scale <-
         role = role,
         trained = trained,
         sds = sds,
+        factor = factor,
         na_rm = na_rm,
         skip = skip,
         id = id
@@ -75,13 +86,14 @@ step_scale <-
   }
 
 step_scale_new <-
-  function(terms, role, trained, sds, na_rm, skip, id) {
+  function(terms, role, trained, sds, factor, na_rm, skip, id) {
     step(
       subclass = "scale",
       terms = terms,
       role = role,
       trained = trained,
       sds = sds,
+      factor = factor,
       na_rm = na_rm,
       skip = skip,
       id = id
@@ -93,13 +105,21 @@ prep.step_scale <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
   check_type(training[, col_names])
 
+  if (x$factor != 1 & x$factor != 2) {
+    rlang::warn("Scaling `factor` should take either a value of 1 or 2")
+  }
+
   sds <-
     vapply(training[, col_names], sd, c(sd = 0), na.rm = x$na_rm)
+
+  sds <- sds * x$factor
+
   step_scale_new(
     terms = x$terms,
     role = x$role,
     trained = TRUE,
     sds,
+    factor = x$factor,
     na_rm = x$na_rm,
     skip = x$skip,
     id = x$id
@@ -110,8 +130,7 @@ prep.step_scale <- function(x, training, info = NULL, ...) {
 bake.step_scale <- function(object, new_data, ...) {
   res <-
     sweep(as.matrix(new_data[, names(object$sds)]), 2, object$sds, "/")
-  if (is.matrix(res) && ncol(res) == 1)
-    res <- res[, 1]
+  res <- tibble::as_tibble(res)
   new_data[, names(object$sds)] <- res
   as_tibble(new_data)
 }
