@@ -19,7 +19,8 @@
 #'  `tidy` method, a tibble with columns `terms` which
 #'  is the columns that will be affected.
 #' @keywords datagen
-#' @concept preprocessing transformation_methods
+#' @concept preprocessing
+#' @concept transformation_methods
 #' @export
 #' @examples
 #' set.seed(313)
@@ -44,7 +45,8 @@
 
 step_sqrt <- function(recipe, ..., role = NA,
                       trained = FALSE, columns = NULL,
-                      skip = FALSE) {
+                      skip = FALSE,
+                      id = rand_id("sqrt")) {
   add_step(
     recipe,
     step_sqrt_new(
@@ -52,22 +54,22 @@ step_sqrt <- function(recipe, ..., role = NA,
       role = role,
       trained = trained,
       columns = columns,
-      skip = skip
+      skip = skip,
+      id = id
     )
   )
 }
 
 step_sqrt_new <-
-  function(terms = NULL, role = NA, trained = FALSE,
-           columns = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, columns, skip, id) {
     step(
       subclass = "sqrt",
       terms = terms,
       role = role,
       trained = trained,
       columns = columns,
-      skip = skip
+      skip = skip,
+      id = id
     )
   }
 
@@ -82,17 +84,18 @@ prep.step_sqrt <- function(x, training, info = NULL, ...) {
     role = x$role,
     trained = TRUE,
     columns = col_names,
-    skip = x$skip
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_sqrt <- function(object, newdata, ...) {
+bake.step_sqrt <- function(object, new_data, ...) {
   col_names <- object$columns
   for (i in seq_along(col_names))
-    newdata[, col_names[i]] <-
-      sqrt(getElement(newdata, col_names[i]))
-  as_tibble(newdata)
+    new_data[, col_names[i]] <-
+      sqrt(getElement(new_data, col_names[i]))
+  as_tibble(new_data)
 }
 
 print.step_sqrt <- function(x, width = max(20, options()$width - 29), ...) {
@@ -103,6 +106,9 @@ print.step_sqrt <- function(x, width = max(20, options()$width - 29), ...) {
 
 #' @rdname step_sqrt
 #' @param x A `step_sqrt` object.
+#' @export
 tidy.step_sqrt <- function(x, ...) {
-  simple_terms(x, ...)
+  res <-simple_terms(x, ...)
+  res$id <- x$id
+  res
 }
